pub struct Registry<ID: Hash + Eq, T> { /* private fields */ }Expand description
A registry is just like a map but supposed to be used with an enum of IDs. It panics in many cases to make sure items are created and deleted in a planned manner. You can also think of it as a cache.
Use-cases: Registering and caching bindgroups, shaders, audio, etc..
The user is heavily adviced to do something like:
#[derive(Debug, Clone, Copy, PartialEq, Eq, Hash)]
enum ExampleId {
A,
B,
C,
}
type ExampleRegistry = Registry<ExampleId, BindGroup>;Implementations