pub struct InputManager { /* private fields */ }Implementations
Sourceimpl InputManager
impl InputManager
pub fn new(max_events: usize, prune_cursor_moved_events: bool) -> Self
pub fn handle_mouse_wheel_input( &mut self, delta: MouseScrollDelta, phase: TouchPhase, )
pub fn handle_cursor_moved(&mut self, position: PhysicalPosition<f64>)
pub fn handle_cursor_left_window(&mut self)
pub fn handle_cursor_entered_window(&mut self)
pub fn pop_event(&mut self) -> Option<(Instant, InputEvent)>
pub fn is_key_pressed(&self, key: &Key) -> bool
pub fn set_key_pressed(&mut self, key: Key, pressed: bool)
pub fn cursor_position(&self) -> PhysicalPosition<f64>
Sourcepub fn cursor_delta(&mut self) -> PhysicalPosition<f64>
pub fn cursor_delta(&mut self) -> PhysicalPosition<f64>
Returns the delta of the cursor position since the last call to this function.
The delta is calculated as the difference between the current cursor position and the cursor position at the last call to this function.